@@ -90,17 +90,23 @@ def tenant_decorator(func):
             if account:
                 tenant = Tenant.objects.filter(account=account).first()
         if tenant:
-            if 'data' in data.keys() and 'ops' in data.keys():
-                data = data.get('data', {})
-            if request.method == 'POST':
-                data['creator'] = tenant.name
-                kwargs["data"] = data
-            ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
-            if not ignore_creator:
-                if "extend_conditions" in kwargs.keys():
-                    kwargs["extend_conditions"]['creator'] = data
+            if isinstance(data, dict):
+                if 'data' in data.keys() and 'ops' in data.keys():
+                    data = data.get('data', {})
+            if request.method == 'POST' or request.method == 'PUT':
+                if isinstance(data, list):
+                    for item in data:
+                        item['creator'] = tenant.name
                 else:
-                    kwargs["extend_conditions"] = {"creator": tenant.name}
+                    data['creator'] = tenant.name
+                kwargs["data"] = data
+            if request.method == 'GET':
+                ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
+                if not ignore_creator:
+                    if "extend_conditions" in kwargs.keys():
+                        kwargs["extend_conditions"]['creator'] = data
+                    else:
+                        kwargs["extend_conditions"] = {"creator": tenant.name}
             return func(obj_view, request, *args, **kwargs)
         else:
             results = Results()
