@@ -9,7 +9,7 @@ from rest_framework.views import APIView
 from common.rest_extend.views.views import Select, BaseView
 
 
-class InjectionData():
+class InjectionData:
     def related_data(self, method):
         related_obj = None
         related_mapping = None
@@ -22,7 +22,6 @@ class InjectionData():
 
 
 class Related(Select):
-
     def execute_related_extend(self, related_obj, related_mapping, data):
         if related_obj and related_mapping:
             for obj in related_obj:
@@ -44,17 +43,19 @@ class Related(Select):
 
     def get_relevance_orm_q(self, obj_name, data):
         conditions = {}
-        for item, value in data.items():
-            if obj_name + "__" in item:
-                conditions[item.replace(obj_name + "__", "")] = value
-        if conditions:
-            orm_q = self.get_orm_q(conditions)
-            return orm_q
+        if data:
+            for item, value in data.items():
+                if obj_name + "__" in item:
+                    conditions[item.replace(obj_name + "__", "")] = value
+            if conditions:
+                orm_q = self.get_orm_q(conditions)
+                return orm_q
 
     def get_relevance_queryset(self, obj, obj_name, data):
         orm_q = self.get_relevance_orm_q(obj_name, data)
-        queryset = obj.objects.filter(orm_q).first()
-        return queryset
+        if orm_q:
+            queryset = obj.objects.filter(orm_q).first()
+            return queryset
 
     def extend_result_field(self, obj_serializer, related_obj, m_to_m_obj, related_mapping, m_to_m_mapping, queryset):
         """
@@ -158,10 +159,10 @@ class RelatedView(BaseView):
 
         try:
             if not related_obj:
-                related_obj, related_mapping = self.injection_data.related_data('GET')
+                related_obj, related_mapping = self.injection_data.related_data("GET")
             if not m_to_m_obj:
-                m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data('GET')
-            if results.data and results.data.result and related_mapping and related_obj:
+                m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data("GET")
+            if results.data and results.data.result:
                 result = self.relate.extend_result_field(
                     obj_serializer, related_obj, m_to_m_obj, related_mapping, m_to_m_mapping, current_page_queryset
                 )
@@ -192,9 +193,9 @@ class RelatedView(BaseView):
             data = data.get("data")
         serializer = obj_serializer(data=data)
         if not related_obj:
-            related_obj, related_mapping = self.injection_data.related_data('POST')
+            related_obj, related_mapping = self.injection_data.related_data("POST")
         if not m_to_m_obj:
-            m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data('POST')
+            m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data("POST")
         self.relate.execute_related_extend(related_obj, related_mapping, data)
         self.relate.execute_m_to_m_extend(m_to_m_obj, m_to_m_mapping, data)
         try:
@@ -221,3 +222,44 @@ class RelatedView(BaseView):
     def extend_page_type_results(self, data, page_type_results, extend_queryset, *args, **kwargs):
         if extend_queryset:
             page_type_results.group = list(extend_queryset)
+
+    def put(
+            self,
+            request,
+            obj,
+            obj_serializer,
+            *,
+            data=None,
+            pk="id",
+            extend_conditions: dict = None,
+            need_results=False,
+            need_queryset=False,
+            related_obj: list = None,
+            m_to_m_obj: list = None,
+            related_mapping=None,
+            m_to_m_mapping=None,
+            **kwargs,
+    ):
+        results = Results()
+        if not data:
+            data = request.data
+        if data.get("data"):
+            data = data.get("data")
+        if not related_obj:
+            related_obj, related_mapping = self.injection_data.related_data("PUT")
+        if not m_to_m_obj:
+            m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data("PUT")
+        self.relate.execute_related_extend(related_obj, related_mapping, data)
+        self.relate.execute_m_to_m_extend(m_to_m_obj, m_to_m_mapping, data)
+
+        return super().put(
+            request,
+            obj,
+            obj_serializer,
+            data=data,
+            pk=pk,
+            extend_conditions=extend_conditions,
+            need_results=need_results,
+            need_queryset=need_queryset,
+            **kwargs,
+        )
